# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.

    The version of the OpenAPI document: v0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_sp_api.generated.financesV0.models.currency import Currency
from typing import Optional, Set
from typing_extensions import Self

class AdjustmentItem(BaseModel):
    """
    An item in an adjustment to the seller's account.
    """ # noqa: E501
    quantity: Optional[StrictStr] = Field(default=None, description="Represents the number of units in the seller's inventory when the AdustmentType is FBAInventoryReimbursement.", alias="Quantity")
    per_unit_amount: Optional[Currency] = Field(default=None, alias="PerUnitAmount")
    total_amount: Optional[Currency] = Field(default=None, alias="TotalAmount")
    seller_sku: Optional[StrictStr] = Field(default=None, description="The seller SKU of the item. The seller SKU is qualified by the seller's seller ID, which is included with every call to the Selling Partner API.", alias="SellerSKU")
    fn_sku: Optional[StrictStr] = Field(default=None, description="A unique identifier assigned to products stored in and fulfilled from a fulfillment center.", alias="FnSKU")
    product_description: Optional[StrictStr] = Field(default=None, description="A short description of the item.", alias="ProductDescription")
    asin: Optional[StrictStr] = Field(default=None, description="The Amazon Standard Identification Number (ASIN) of the item.", alias="ASIN")
    transaction_number: Optional[StrictStr] = Field(default=None, description="The transaction number that is related to the adjustment.", alias="TransactionNumber")
    __properties: ClassVar[List[str]] = ["Quantity", "PerUnitAmount", "TotalAmount", "SellerSKU", "FnSKU", "ProductDescription", "ASIN", "TransactionNumber"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AdjustmentItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of per_unit_amount
        if self.per_unit_amount:
            _dict['PerUnitAmount'] = self.per_unit_amount.to_dict()
        # override the default output from pydantic by calling `to_dict()` of total_amount
        if self.total_amount:
            _dict['TotalAmount'] = self.total_amount.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AdjustmentItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "Quantity": obj.get("Quantity"),
            "PerUnitAmount": Currency.from_dict(obj["PerUnitAmount"]) if obj.get("PerUnitAmount") is not None else None,
            "TotalAmount": Currency.from_dict(obj["TotalAmount"]) if obj.get("TotalAmount") is not None else None,
            "SellerSKU": obj.get("SellerSKU"),
            "FnSKU": obj.get("FnSKU"),
            "ProductDescription": obj.get("ProductDescription"),
            "ASIN": obj.get("ASIN"),
            "TransactionNumber": obj.get("TransactionNumber")
        })
        return _obj


