# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.

    The version of the OpenAPI document: v0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_sp_api.generated.financesV0.models.charge_component import ChargeComponent
from py_sp_api.generated.financesV0.models.fee_component import FeeComponent
from typing import Optional, Set
from typing_extensions import Self

class PayWithAmazonEvent(BaseModel):
    """
    An event related to the seller's Pay with Amazon account.
    """ # noqa: E501
    seller_order_id: Optional[StrictStr] = Field(default=None, description="An order identifier that is specified by the seller.", alias="SellerOrderId")
    transaction_posted_date: Optional[datetime] = Field(default=None, description="Fields with a schema type of date are in ISO 8601 date time format (for example GroupBeginDate).", alias="TransactionPostedDate")
    business_object_type: Optional[StrictStr] = Field(default=None, description="The type of business object.", alias="BusinessObjectType")
    sales_channel: Optional[StrictStr] = Field(default=None, description="The sales channel for the transaction.", alias="SalesChannel")
    charge: Optional[ChargeComponent] = Field(default=None, alias="Charge")
    fee_list: Optional[List[FeeComponent]] = Field(default=None, description="A list of fee component information.", alias="FeeList")
    payment_amount_type: Optional[StrictStr] = Field(default=None, description="The type of payment.  Possible values:  * Sales", alias="PaymentAmountType")
    amount_description: Optional[StrictStr] = Field(default=None, description="A short description of this payment event.", alias="AmountDescription")
    fulfillment_channel: Optional[StrictStr] = Field(default=None, description="The fulfillment channel.  Possible values:  * AFN - Amazon Fulfillment Network (Fulfillment by Amazon)  * MFN - Merchant Fulfillment Network (self-fulfilled)", alias="FulfillmentChannel")
    store_name: Optional[StrictStr] = Field(default=None, description="The store name where the event occurred.", alias="StoreName")
    __properties: ClassVar[List[str]] = ["SellerOrderId", "TransactionPostedDate", "BusinessObjectType", "SalesChannel", "Charge", "FeeList", "PaymentAmountType", "AmountDescription", "FulfillmentChannel", "StoreName"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PayWithAmazonEvent from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of charge
        if self.charge:
            _dict['Charge'] = self.charge.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in fee_list (list)
        _items = []
        if self.fee_list:
            for _item_fee_list in self.fee_list:
                if _item_fee_list:
                    _items.append(_item_fee_list.to_dict())
            _dict['FeeList'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PayWithAmazonEvent from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "SellerOrderId": obj.get("SellerOrderId"),
            "TransactionPostedDate": obj.get("TransactionPostedDate"),
            "BusinessObjectType": obj.get("BusinessObjectType"),
            "SalesChannel": obj.get("SalesChannel"),
            "Charge": ChargeComponent.from_dict(obj["Charge"]) if obj.get("Charge") is not None else None,
            "FeeList": [FeeComponent.from_dict(_item) for _item in obj["FeeList"]] if obj.get("FeeList") is not None else None,
            "PaymentAmountType": obj.get("PaymentAmountType"),
            "AmountDescription": obj.get("AmountDescription"),
            "FulfillmentChannel": obj.get("FulfillmentChannel"),
            "StoreName": obj.get("StoreName")
        })
        return _obj


