# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.

    The version of the OpenAPI document: v0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_sp_api.generated.financesV0.models.currency import Currency
from py_sp_api.generated.financesV0.models.safet_reimbursement_item import SAFETReimbursementItem
from typing import Optional, Set
from typing_extensions import Self

class SAFETReimbursementEvent(BaseModel):
    """
    A SAFE-T claim reimbursement on the seller's account.
    """ # noqa: E501
    posted_date: Optional[datetime] = Field(default=None, description="Fields with a schema type of date are in ISO 8601 date time format (for example GroupBeginDate).", alias="PostedDate")
    safet_claim_id: Optional[StrictStr] = Field(default=None, description="A SAFE-T claim identifier.", alias="SAFETClaimId")
    reimbursed_amount: Optional[Currency] = Field(default=None, alias="ReimbursedAmount")
    reason_code: Optional[StrictStr] = Field(default=None, description="Indicates why the seller was reimbursed.", alias="ReasonCode")
    safet_reimbursement_item_list: Optional[List[SAFETReimbursementItem]] = Field(default=None, description="A list of SAFETReimbursementItems.", alias="SAFETReimbursementItemList")
    __properties: ClassVar[List[str]] = ["PostedDate", "SAFETClaimId", "ReimbursedAmount", "ReasonCode", "SAFETReimbursementItemList"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SAFETReimbursementEvent from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of reimbursed_amount
        if self.reimbursed_amount:
            _dict['ReimbursedAmount'] = self.reimbursed_amount.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in safet_reimbursement_item_list (list)
        _items = []
        if self.safet_reimbursement_item_list:
            for _item_safet_reimbursement_item_list in self.safet_reimbursement_item_list:
                if _item_safet_reimbursement_item_list:
                    _items.append(_item_safet_reimbursement_item_list.to_dict())
            _dict['SAFETReimbursementItemList'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SAFETReimbursementEvent from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "PostedDate": obj.get("PostedDate"),
            "SAFETClaimId": obj.get("SAFETClaimId"),
            "ReimbursedAmount": Currency.from_dict(obj["ReimbursedAmount"]) if obj.get("ReimbursedAmount") is not None else None,
            "ReasonCode": obj.get("ReasonCode"),
            "SAFETReimbursementItemList": [SAFETReimbursementItem.from_dict(_item) for _item in obj["SAFETReimbursementItemList"]] if obj.get("SAFETReimbursementItemList") is not None else None
        })
        return _obj


