# coding: utf-8

"""
    Fulfillment Inbound v2024-03-20

    The Selling Partner API for Fulfillment By Amazon (FBA) Inbound. The FBA Inbound API enables building inbound workflows to create, manage, and send shipments into Amazon's fulfillment network. The API has interoperability with the Send-to-Amazon user interface.

    The version of the OpenAPI document: 2024-03-20
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from py_sp_api.generated.fulfillmentInbound_2024_03_20.models.incentive import Incentive
from py_sp_api.generated.fulfillmentInbound_2024_03_20.models.shipping_configuration import ShippingConfiguration
from typing import Optional, Set
from typing_extensions import Self

class PackingOption(BaseModel):
    """
    A packing option contains a set of pack groups plus additional information about the packing option, such as any discounts or fees if it's selected.
    """ # noqa: E501
    discounts: List[Incentive] = Field(description="Discount for the offered option.")
    expiration: Optional[datetime] = Field(default=None, description="The time at which this packing option is no longer valid. In [ISO 8601](https://developer-docs.amazon.com/sp-api/docs/iso-8601) datetime format with pattern `yyyy-MM-ddTHH:mm:ss.sssZ`.")
    fees: List[Incentive] = Field(description="Fee for the offered option.")
    packing_groups: List[Annotated[str, Field(min_length=38, strict=True, max_length=38)]] = Field(description="Packing group IDs.", alias="packingGroups")
    packing_option_id: Annotated[str, Field(min_length=38, strict=True, max_length=38)] = Field(description="Identifier of a packing option.", alias="packingOptionId")
    status: Annotated[str, Field(min_length=1, strict=True, max_length=1024)] = Field(description="The status of the packing option. Possible values: `OFFERED`, `ACCEPTED`, `EXPIRED`.")
    supported_shipping_configurations: List[ShippingConfiguration] = Field(description="List of supported shipping modes.", alias="supportedShippingConfigurations")
    __properties: ClassVar[List[str]] = ["discounts", "expiration", "fees", "packingGroups", "packingOptionId", "status", "supportedShippingConfigurations"]

    @field_validator('packing_option_id')
    def packing_option_id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[a-zA-Z0-9-]*$", value):
            raise ValueError(r"must validate the regular expression /^[a-zA-Z0-9-]*$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PackingOption from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in discounts (list)
        _items = []
        if self.discounts:
            for _item_discounts in self.discounts:
                if _item_discounts:
                    _items.append(_item_discounts.to_dict())
            _dict['discounts'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in fees (list)
        _items = []
        if self.fees:
            for _item_fees in self.fees:
                if _item_fees:
                    _items.append(_item_fees.to_dict())
            _dict['fees'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in supported_shipping_configurations (list)
        _items = []
        if self.supported_shipping_configurations:
            for _item_supported_shipping_configurations in self.supported_shipping_configurations:
                if _item_supported_shipping_configurations:
                    _items.append(_item_supported_shipping_configurations.to_dict())
            _dict['supportedShippingConfigurations'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PackingOption from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "discounts": [Incentive.from_dict(_item) for _item in obj["discounts"]] if obj.get("discounts") is not None else None,
            "expiration": obj.get("expiration"),
            "fees": [Incentive.from_dict(_item) for _item in obj["fees"]] if obj.get("fees") is not None else None,
            "packingGroups": obj.get("packingGroups"),
            "packingOptionId": obj.get("packingOptionId"),
            "status": obj.get("status"),
            "supportedShippingConfigurations": [ShippingConfiguration.from_dict(_item) for _item in obj["supportedShippingConfigurations"]] if obj.get("supportedShippingConfigurations") is not None else None
        })
        return _obj


