# coding: utf-8

"""
    Selling Partner APIs for Fulfillment Outbound

    The Selling Partner API for Fulfillment Outbound lets you create applications that help a seller fulfill Multi-Channel Fulfillment orders using their inventory in Amazon's fulfillment network. You can get information on both potential and existing fulfillment orders.

    The version of the OpenAPI document: 2020-07-01
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from py_sp_api.generated.fulfillmentOutbound_2020_07_01.models.weight import Weight
from typing import Optional, Set
from typing_extensions import Self

class FulfillmentPreviewItem(BaseModel):
    """
    Item information for a shipment in a fulfillment order preview.
    """ # noqa: E501
    seller_sku: StrictStr = Field(description="The seller SKU of the item.", alias="sellerSku")
    quantity: StrictInt = Field(description="The item quantity.")
    seller_fulfillment_order_item_id: StrictStr = Field(description="A fulfillment order item identifier that the seller created with a call to the `createFulfillmentOrder` operation.", alias="sellerFulfillmentOrderItemId")
    estimated_shipping_weight: Optional[Weight] = Field(default=None, alias="estimatedShippingWeight")
    shipping_weight_calculation_method: Optional[StrictStr] = Field(default=None, description="The method used to calculate the estimated shipping weight.", alias="shippingWeightCalculationMethod")
    __properties: ClassVar[List[str]] = ["sellerSku", "quantity", "sellerFulfillmentOrderItemId", "estimatedShippingWeight", "shippingWeightCalculationMethod"]

    @field_validator('shipping_weight_calculation_method')
    def shipping_weight_calculation_method_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Package', 'Dimensional']):
            raise ValueError("must be one of enum values ('Package', 'Dimensional')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FulfillmentPreviewItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of estimated_shipping_weight
        if self.estimated_shipping_weight:
            _dict['estimatedShippingWeight'] = self.estimated_shipping_weight.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FulfillmentPreviewItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "sellerSku": obj.get("sellerSku"),
            "quantity": obj.get("quantity"),
            "sellerFulfillmentOrderItemId": obj.get("sellerFulfillmentOrderItemId"),
            "estimatedShippingWeight": Weight.from_dict(obj["estimatedShippingWeight"]) if obj.get("estimatedShippingWeight") is not None else None,
            "shippingWeightCalculationMethod": obj.get("shippingWeightCalculationMethod")
        })
        return _obj


