# coding: utf-8

"""
    Selling Partner API for Listings Items

    The Selling Partner API for Listings Items (Listings Items API) provides programmatic access to selling partner listings on Amazon. Use this API in collaboration with the Selling Partner API for Product Type Definitions, which you use to retrieve the information about Amazon product types needed to use the Listings Items API.  For more information, see the [Listings Items API Use Case Guide](https://developer-docs.amazon.com/sp-api/docs/listings-items-api-v2021-08-01-use-case-guide).

    The version of the OpenAPI document: 2021-08-01
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from py_sp_api.generated.listingsItems_2021_08_01.models.item_variation_theme import ItemVariationTheme
from typing import Optional, Set
from typing_extensions import Self

class ItemRelationship(BaseModel):
    """
    the relationship details for a listing item.
    """ # noqa: E501
    child_skus: Optional[List[StrictStr]] = Field(default=None, description="Identifiers (SKUs) of the related items that are children of this listing item.", alias="childSkus")
    parent_skus: Optional[List[StrictStr]] = Field(default=None, description="Identifiers (SKUs) of the related items that are parents of this listing item.", alias="parentSkus")
    variation_theme: Optional[ItemVariationTheme] = Field(default=None, alias="variationTheme")
    type: StrictStr = Field(description="The type of relationship.")
    __properties: ClassVar[List[str]] = ["childSkus", "parentSkus", "variationTheme", "type"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['VARIATION', 'PACKAGE_HIERARCHY']):
            raise ValueError("must be one of enum values ('VARIATION', 'PACKAGE_HIERARCHY')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ItemRelationship from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of variation_theme
        if self.variation_theme:
            _dict['variationTheme'] = self.variation_theme.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ItemRelationship from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "childSkus": obj.get("childSkus"),
            "parentSkus": obj.get("parentSkus"),
            "variationTheme": ItemVariationTheme.from_dict(obj["variationTheme"]) if obj.get("variationTheme") is not None else None,
            "type": obj.get("type")
        })
        return _obj


