# coding: utf-8

"""
    The Selling Partner API for Sellers

    The Selling Partner API for Sellers lets you retrieve information on behalf of sellers about their seller account, such as the marketplaces they participate in. Along with listing the marketplaces that a seller can sell in, the API also provides additional information about the marketplace such as the default language and the default currency. The API also provides seller-specific information such as whether the seller has suspended listings in that marketplace.

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from py_sp_api.generated.sellers.models.business import Business
from py_sp_api.generated.sellers.models.marketplace_participation import MarketplaceParticipation
from py_sp_api.generated.sellers.models.primary_contact import PrimaryContact
from typing import Optional, Set
from typing_extensions import Self

class Account(BaseModel):
    """
    The response schema for the `getAccount` operation.
    """ # noqa: E501
    marketplace_participation_list: List[MarketplaceParticipation] = Field(description="List of marketplace participations.", alias="marketplaceParticipationList")
    business_type: StrictStr = Field(description="The type of business registered for the seller account.", alias="businessType")
    selling_plan: StrictStr = Field(description="The selling plan details.", alias="sellingPlan")
    business: Optional[Business] = None
    primary_contact: Optional[PrimaryContact] = Field(default=None, alias="primaryContact")
    __properties: ClassVar[List[str]] = ["marketplaceParticipationList", "businessType", "sellingPlan", "business", "primaryContact"]

    @field_validator('business_type')
    def business_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['CHARITY', 'CRAFTSMAN', 'NATURAL_PERSON_COMPANY', 'PUBLIC_LISTED', 'PRIVATE_LIMITED', 'SOLE_PROPRIETORSHIP', 'STATE_OWNED', 'INDIVIDUAL']):
            raise ValueError("must be one of enum values ('CHARITY', 'CRAFTSMAN', 'NATURAL_PERSON_COMPANY', 'PUBLIC_LISTED', 'PRIVATE_LIMITED', 'SOLE_PROPRIETORSHIP', 'STATE_OWNED', 'INDIVIDUAL')")
        return value

    @field_validator('selling_plan')
    def selling_plan_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['PROFESSIONAL', 'INDIVIDUAL']):
            raise ValueError("must be one of enum values ('PROFESSIONAL', 'INDIVIDUAL')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Account from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in marketplace_participation_list (list)
        _items = []
        if self.marketplace_participation_list:
            for _item_marketplace_participation_list in self.marketplace_participation_list:
                if _item_marketplace_participation_list:
                    _items.append(_item_marketplace_participation_list.to_dict())
            _dict['marketplaceParticipationList'] = _items
        # override the default output from pydantic by calling `to_dict()` of business
        if self.business:
            _dict['business'] = self.business.to_dict()
        # override the default output from pydantic by calling `to_dict()` of primary_contact
        if self.primary_contact:
            _dict['primaryContact'] = self.primary_contact.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Account from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "marketplaceParticipationList": [MarketplaceParticipation.from_dict(_item) for _item in obj["marketplaceParticipationList"]] if obj.get("marketplaceParticipationList") is not None else None,
            "businessType": obj.get("businessType"),
            "sellingPlan": obj.get("sellingPlan"),
            "business": Business.from_dict(obj["business"]) if obj.get("business") is not None else None,
            "primaryContact": PrimaryContact.from_dict(obj["primaryContact"]) if obj.get("primaryContact") is not None else None
        })
        return _obj


