# coding: utf-8

"""
    Amazon Shipping API

    The Amazon Shipping API is designed to support outbound shipping use cases both for orders originating on Amazon-owned marketplaces as well as external channels/marketplaces. With these APIs, you can request shipping rates, create shipments, cancel shipments, and track shipments.

    The version of the OpenAPI document: v2
    Contact: swa-api-core@amazon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List
from py_sp_api.generated.shippingV2.models.event import Event
from py_sp_api.generated.shippingV2.models.tracking_summary import TrackingSummary
from typing import Optional, Set
from typing_extensions import Self

class GetTrackingResult(BaseModel):
    """
    The payload for the getTracking operation.
    """ # noqa: E501
    tracking_id: StrictStr = Field(description="The carrier generated identifier for a package in a purchased shipment.", alias="trackingId")
    alternate_leg_tracking_id: StrictStr = Field(description="The carrier generated reverse identifier for a returned package in a purchased shipment.", alias="alternateLegTrackingId")
    event_history: List[Event] = Field(description="A list of tracking events.", alias="eventHistory")
    promised_delivery_date: datetime = Field(description="The date and time by which the shipment is promised to be delivered.", alias="promisedDeliveryDate")
    summary: TrackingSummary
    __properties: ClassVar[List[str]] = ["trackingId", "alternateLegTrackingId", "eventHistory", "promisedDeliveryDate", "summary"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GetTrackingResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in event_history (list)
        _items = []
        if self.event_history:
            for _item_event_history in self.event_history:
                if _item_event_history:
                    _items.append(_item_event_history.to_dict())
            _dict['eventHistory'] = _items
        # override the default output from pydantic by calling `to_dict()` of summary
        if self.summary:
            _dict['summary'] = self.summary.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GetTrackingResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "trackingId": obj.get("trackingId"),
            "alternateLegTrackingId": obj.get("alternateLegTrackingId"),
            "eventHistory": [Event.from_dict(_item) for _item in obj["eventHistory"]] if obj.get("eventHistory") is not None else None,
            "promisedDeliveryDate": obj.get("promisedDeliveryDate"),
            "summary": TrackingSummary.from_dict(obj["summary"]) if obj.get("summary") is not None else None
        })
        return _obj


