# coding: utf-8

"""
    Amazon Shipping API

    The Amazon Shipping API is designed to support outbound shipping use cases both for orders originating on Amazon-owned marketplaces as well as external channels/marketplaces. With these APIs, you can request shipping rates, create shipments, cancel shipments, and track shipments.

    The version of the OpenAPI document: v2
    Contact: swa-api-core@amazon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List
from py_sp_api.generated.shippingV2.models.ineligibility_reason import IneligibilityReason
from typing import Optional, Set
from typing_extensions import Self

class IneligibleRate(BaseModel):
    """
    Detailed information for an ineligible shipping service offering.
    """ # noqa: E501
    service_id: StrictStr = Field(description="An identifier for the shipping service.", alias="serviceId")
    service_name: StrictStr = Field(description="The name of the shipping service.", alias="serviceName")
    carrier_name: StrictStr = Field(description="The carrier name for the offering.", alias="carrierName")
    carrier_id: StrictStr = Field(description="The carrier identifier for the offering, provided by the carrier.", alias="carrierId")
    ineligibility_reasons: List[IneligibilityReason] = Field(description="A list of reasons why a shipping service offering is ineligible.", alias="ineligibilityReasons")
    __properties: ClassVar[List[str]] = ["serviceId", "serviceName", "carrierName", "carrierId", "ineligibilityReasons"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IneligibleRate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in ineligibility_reasons (list)
        _items = []
        if self.ineligibility_reasons:
            for _item_ineligibility_reasons in self.ineligibility_reasons:
                if _item_ineligibility_reasons:
                    _items.append(_item_ineligibility_reasons.to_dict())
            _dict['ineligibilityReasons'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IneligibleRate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "serviceId": obj.get("serviceId"),
            "serviceName": obj.get("serviceName"),
            "carrierName": obj.get("carrierName"),
            "carrierId": obj.get("carrierId"),
            "ineligibilityReasons": [IneligibilityReason.from_dict(_item) for _item in obj["ineligibilityReasons"]] if obj.get("ineligibilityReasons") is not None else None
        })
        return _obj


