# coding: utf-8

"""
    Amazon Shipping API

    The Amazon Shipping API is designed to support outbound shipping use cases both for orders originating on Amazon-owned marketplaces as well as external channels/marketplaces. With these APIs, you can request shipping rates, create shipments, cancel shipments, and track shipments.

    The version of the OpenAPI document: v2
    Contact: swa-api-core@amazon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from py_sp_api.generated.shippingV2.models.access_point_details import AccessPointDetails
from py_sp_api.generated.shippingV2.models.address import Address
from py_sp_api.generated.shippingV2.models.channel_details import ChannelDetails
from py_sp_api.generated.shippingV2.models.one_click_shipment_value_added_service import OneClickShipmentValueAddedService
from py_sp_api.generated.shippingV2.models.package import Package
from py_sp_api.generated.shippingV2.models.requested_document_specification import RequestedDocumentSpecification
from py_sp_api.generated.shippingV2.models.service_selection import ServiceSelection
from py_sp_api.generated.shippingV2.models.shipper_instruction import ShipperInstruction
from py_sp_api.generated.shippingV2.models.tax_detail import TaxDetail
from typing import Optional, Set
from typing_extensions import Self

class OneClickShipmentRequest(BaseModel):
    """
    The request schema for the OneClickShipment operation. When the channelType is not Amazon, shipTo is required and when channelType is Amazon shipTo is ignored.
    """ # noqa: E501
    ship_to: Optional[Address] = Field(default=None, alias="shipTo")
    ship_from: Address = Field(alias="shipFrom")
    return_to: Optional[Address] = Field(default=None, alias="returnTo")
    ship_date: Optional[datetime] = Field(default=None, description="The ship date and time (the requested pickup). This defaults to the current date and time.", alias="shipDate")
    packages: List[Package] = Field(description="A list of packages to be shipped through a shipping service offering.")
    value_added_services_details: Optional[List[OneClickShipmentValueAddedService]] = Field(default=None, description="The value-added services to be added to a shipping service purchase.", alias="valueAddedServicesDetails")
    tax_details: Optional[List[TaxDetail]] = Field(default=None, description="A list of tax detail information.", alias="taxDetails")
    channel_details: ChannelDetails = Field(alias="channelDetails")
    label_specifications: RequestedDocumentSpecification = Field(alias="labelSpecifications")
    service_selection: ServiceSelection = Field(alias="serviceSelection")
    shipper_instruction: Optional[ShipperInstruction] = Field(default=None, alias="shipperInstruction")
    destination_access_point_details: Optional[AccessPointDetails] = Field(default=None, alias="destinationAccessPointDetails")
    __properties: ClassVar[List[str]] = ["shipTo", "shipFrom", "returnTo", "shipDate", "packages", "valueAddedServicesDetails", "taxDetails", "channelDetails", "labelSpecifications", "serviceSelection", "shipperInstruction", "destinationAccessPointDetails"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OneClickShipmentRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of ship_to
        if self.ship_to:
            _dict['shipTo'] = self.ship_to.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ship_from
        if self.ship_from:
            _dict['shipFrom'] = self.ship_from.to_dict()
        # override the default output from pydantic by calling `to_dict()` of return_to
        if self.return_to:
            _dict['returnTo'] = self.return_to.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in packages (list)
        _items = []
        if self.packages:
            for _item_packages in self.packages:
                if _item_packages:
                    _items.append(_item_packages.to_dict())
            _dict['packages'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in value_added_services_details (list)
        _items = []
        if self.value_added_services_details:
            for _item_value_added_services_details in self.value_added_services_details:
                if _item_value_added_services_details:
                    _items.append(_item_value_added_services_details.to_dict())
            _dict['valueAddedServicesDetails'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in tax_details (list)
        _items = []
        if self.tax_details:
            for _item_tax_details in self.tax_details:
                if _item_tax_details:
                    _items.append(_item_tax_details.to_dict())
            _dict['taxDetails'] = _items
        # override the default output from pydantic by calling `to_dict()` of channel_details
        if self.channel_details:
            _dict['channelDetails'] = self.channel_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of label_specifications
        if self.label_specifications:
            _dict['labelSpecifications'] = self.label_specifications.to_dict()
        # override the default output from pydantic by calling `to_dict()` of service_selection
        if self.service_selection:
            _dict['serviceSelection'] = self.service_selection.to_dict()
        # override the default output from pydantic by calling `to_dict()` of shipper_instruction
        if self.shipper_instruction:
            _dict['shipperInstruction'] = self.shipper_instruction.to_dict()
        # override the default output from pydantic by calling `to_dict()` of destination_access_point_details
        if self.destination_access_point_details:
            _dict['destinationAccessPointDetails'] = self.destination_access_point_details.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OneClickShipmentRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "shipTo": Address.from_dict(obj["shipTo"]) if obj.get("shipTo") is not None else None,
            "shipFrom": Address.from_dict(obj["shipFrom"]) if obj.get("shipFrom") is not None else None,
            "returnTo": Address.from_dict(obj["returnTo"]) if obj.get("returnTo") is not None else None,
            "shipDate": obj.get("shipDate"),
            "packages": [Package.from_dict(_item) for _item in obj["packages"]] if obj.get("packages") is not None else None,
            "valueAddedServicesDetails": [OneClickShipmentValueAddedService.from_dict(_item) for _item in obj["valueAddedServicesDetails"]] if obj.get("valueAddedServicesDetails") is not None else None,
            "taxDetails": [TaxDetail.from_dict(_item) for _item in obj["taxDetails"]] if obj.get("taxDetails") is not None else None,
            "channelDetails": ChannelDetails.from_dict(obj["channelDetails"]) if obj.get("channelDetails") is not None else None,
            "labelSpecifications": RequestedDocumentSpecification.from_dict(obj["labelSpecifications"]) if obj.get("labelSpecifications") is not None else None,
            "serviceSelection": ServiceSelection.from_dict(obj["serviceSelection"]) if obj.get("serviceSelection") is not None else None,
            "shipperInstruction": ShipperInstruction.from_dict(obj["shipperInstruction"]) if obj.get("shipperInstruction") is not None else None,
            "destinationAccessPointDetails": AccessPointDetails.from_dict(obj["destinationAccessPointDetails"]) if obj.get("destinationAccessPointDetails") is not None else None
        })
        return _obj


