# coding: utf-8

"""
    Selling Partner API for Direct Fulfillment Shipping

    The Selling Partner API for Direct Fulfillment Shipping provides programmatic access to a direct fulfillment vendor's shipping data.

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from py_sp_api.generated.vendorDirectFulfillmentShippingV1.models.dimensions import Dimensions
from py_sp_api.generated.vendorDirectFulfillmentShippingV1.models.packed_item import PackedItem
from py_sp_api.generated.vendorDirectFulfillmentShippingV1.models.weight import Weight
from typing import Optional, Set
from typing_extensions import Self

class Container(BaseModel):
    """
    A container used for shipping and packing items.
    """ # noqa: E501
    container_type: StrictStr = Field(description="The type of container.", alias="containerType")
    container_identifier: StrictStr = Field(description="The container identifier.", alias="containerIdentifier")
    tracking_number: Optional[StrictStr] = Field(default=None, description="The tracking number.", alias="trackingNumber")
    manifest_id: Optional[StrictStr] = Field(default=None, description="The manifest identifier.", alias="manifestId")
    manifest_date: Optional[StrictStr] = Field(default=None, description="The date of the manifest.", alias="manifestDate")
    ship_method: Optional[StrictStr] = Field(default=None, description="The shipment method.", alias="shipMethod")
    scac_code: Optional[StrictStr] = Field(default=None, description="SCAC code required for NA VOC vendors only.", alias="scacCode")
    carrier: Optional[StrictStr] = Field(default=None, description="Carrier required for EU VOC vendors only.")
    container_sequence_number: Optional[StrictInt] = Field(default=None, description="An integer that must be submitted for multi-box shipments only, where one item may come in separate packages.", alias="containerSequenceNumber")
    dimensions: Optional[Dimensions] = None
    weight: Weight
    packed_items: List[PackedItem] = Field(description="A list of packed items.", alias="packedItems")
    __properties: ClassVar[List[str]] = ["containerType", "containerIdentifier", "trackingNumber", "manifestId", "manifestDate", "shipMethod", "scacCode", "carrier", "containerSequenceNumber", "dimensions", "weight", "packedItems"]

    @field_validator('container_type')
    def container_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['carton', 'pallet']):
            raise ValueError("must be one of enum values ('carton', 'pallet')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Container from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of dimensions
        if self.dimensions:
            _dict['dimensions'] = self.dimensions.to_dict()
        # override the default output from pydantic by calling `to_dict()` of weight
        if self.weight:
            _dict['weight'] = self.weight.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in packed_items (list)
        _items = []
        if self.packed_items:
            for _item_packed_items in self.packed_items:
                if _item_packed_items:
                    _items.append(_item_packed_items.to_dict())
            _dict['packedItems'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Container from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "containerType": obj.get("containerType"),
            "containerIdentifier": obj.get("containerIdentifier"),
            "trackingNumber": obj.get("trackingNumber"),
            "manifestId": obj.get("manifestId"),
            "manifestDate": obj.get("manifestDate"),
            "shipMethod": obj.get("shipMethod"),
            "scacCode": obj.get("scacCode"),
            "carrier": obj.get("carrier"),
            "containerSequenceNumber": obj.get("containerSequenceNumber"),
            "dimensions": Dimensions.from_dict(obj["dimensions"]) if obj.get("dimensions") is not None else None,
            "weight": Weight.from_dict(obj["weight"]) if obj.get("weight") is not None else None,
            "packedItems": [PackedItem.from_dict(_item) for _item in obj["packedItems"]] if obj.get("packedItems") is not None else None
        })
        return _obj


