# coding: utf-8

"""
    Vendor Invoices v1

    The Selling Partner API for Retail Procurement Payments provides programmatic access to vendors payments data.

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_sp_api.generated.vendorInvoices.models.allowance_details import AllowanceDetails
from py_sp_api.generated.vendorInvoices.models.charge_details import ChargeDetails
from py_sp_api.generated.vendorInvoices.models.credit_note_details import CreditNoteDetails
from py_sp_api.generated.vendorInvoices.models.item_quantity import ItemQuantity
from py_sp_api.generated.vendorInvoices.models.money import Money
from py_sp_api.generated.vendorInvoices.models.net_cost_unit_of_measure import NetCostUnitOfMeasure
from py_sp_api.generated.vendorInvoices.models.tax_details import TaxDetails
from typing import Optional, Set
from typing_extensions import Self

class InvoiceItem(BaseModel):
    """
    Details of the item being invoiced.
    """ # noqa: E501
    item_sequence_number: StrictInt = Field(description="Unique number related to this line item.", alias="itemSequenceNumber")
    amazon_product_identifier: Optional[StrictStr] = Field(default=None, description="Amazon Standard Identification Number (ASIN) of an item.", alias="amazonProductIdentifier")
    vendor_product_identifier: Optional[StrictStr] = Field(default=None, description="The vendor selected product identifier of the item. Should be the same as was provided in the purchase order.", alias="vendorProductIdentifier")
    invoiced_quantity: ItemQuantity = Field(alias="invoicedQuantity")
    net_cost: Money = Field(alias="netCost")
    net_cost_unit_of_measure: Optional[NetCostUnitOfMeasure] = Field(default=None, alias="netCostUnitOfMeasure")
    purchase_order_number: Optional[StrictStr] = Field(default=None, description="The Amazon purchase order number for this invoiced line item. Formatting Notes: 8-character alpha-numeric code. This value is mandatory only when invoiceType is Invoice, and is not required when invoiceType is CreditNote.", alias="purchaseOrderNumber")
    hsn_code: Optional[StrictStr] = Field(default=None, description="HSN Tax code. The HSN number cannot contain alphabets.", alias="hsnCode")
    credit_note_details: Optional[CreditNoteDetails] = Field(default=None, alias="creditNoteDetails")
    tax_details: Optional[List[TaxDetails]] = Field(default=None, description="Individual tax details per line item.", alias="taxDetails")
    charge_details: Optional[List[ChargeDetails]] = Field(default=None, description="Individual charge details per line item.", alias="chargeDetails")
    allowance_details: Optional[List[AllowanceDetails]] = Field(default=None, description="Individual allowance details per line item.", alias="allowanceDetails")
    __properties: ClassVar[List[str]] = ["itemSequenceNumber", "amazonProductIdentifier", "vendorProductIdentifier", "invoicedQuantity", "netCost", "netCostUnitOfMeasure", "purchaseOrderNumber", "hsnCode", "creditNoteDetails", "taxDetails", "chargeDetails", "allowanceDetails"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of InvoiceItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of invoiced_quantity
        if self.invoiced_quantity:
            _dict['invoicedQuantity'] = self.invoiced_quantity.to_dict()
        # override the default output from pydantic by calling `to_dict()` of net_cost
        if self.net_cost:
            _dict['netCost'] = self.net_cost.to_dict()
        # override the default output from pydantic by calling `to_dict()` of credit_note_details
        if self.credit_note_details:
            _dict['creditNoteDetails'] = self.credit_note_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in tax_details (list)
        _items = []
        if self.tax_details:
            for _item_tax_details in self.tax_details:
                if _item_tax_details:
                    _items.append(_item_tax_details.to_dict())
            _dict['taxDetails'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in charge_details (list)
        _items = []
        if self.charge_details:
            for _item_charge_details in self.charge_details:
                if _item_charge_details:
                    _items.append(_item_charge_details.to_dict())
            _dict['chargeDetails'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in allowance_details (list)
        _items = []
        if self.allowance_details:
            for _item_allowance_details in self.allowance_details:
                if _item_allowance_details:
                    _items.append(_item_allowance_details.to_dict())
            _dict['allowanceDetails'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of InvoiceItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "itemSequenceNumber": obj.get("itemSequenceNumber"),
            "amazonProductIdentifier": obj.get("amazonProductIdentifier"),
            "vendorProductIdentifier": obj.get("vendorProductIdentifier"),
            "invoicedQuantity": ItemQuantity.from_dict(obj["invoicedQuantity"]) if obj.get("invoicedQuantity") is not None else None,
            "netCost": Money.from_dict(obj["netCost"]) if obj.get("netCost") is not None else None,
            "netCostUnitOfMeasure": obj.get("netCostUnitOfMeasure"),
            "purchaseOrderNumber": obj.get("purchaseOrderNumber"),
            "hsnCode": obj.get("hsnCode"),
            "creditNoteDetails": CreditNoteDetails.from_dict(obj["creditNoteDetails"]) if obj.get("creditNoteDetails") is not None else None,
            "taxDetails": [TaxDetails.from_dict(_item) for _item in obj["taxDetails"]] if obj.get("taxDetails") is not None else None,
            "chargeDetails": [ChargeDetails.from_dict(_item) for _item in obj["chargeDetails"]] if obj.get("chargeDetails") is not None else None,
            "allowanceDetails": [AllowanceDetails.from_dict(_item) for _item in obj["allowanceDetails"]] if obj.get("allowanceDetails") is not None else None
        })
        return _obj


