# coding: utf-8

"""
    Selling Partner API for Retail Procurement Shipments

    The Selling Partner API for Retail Procurement Shipments provides programmatic access to retail shipping data for vendors.

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from py_sp_api.generated.vendorShipments.models.container_identification import ContainerIdentification
from py_sp_api.generated.vendorShipments.models.dimensions import Dimensions
from py_sp_api.generated.vendorShipments.models.inner_containers_details import InnerContainersDetails
from py_sp_api.generated.vendorShipments.models.packed_items import PackedItems
from py_sp_api.generated.vendorShipments.models.weight import Weight
from typing import Optional, Set
from typing_extensions import Self

class Containers(BaseModel):
    """
    A list of the items in this transportation and their associated inner container details. If any of the item detail fields are common at a carton or a pallet level, provide them at the corresponding carton or pallet level.
    """ # noqa: E501
    container_type: StrictStr = Field(description="The type of container.", alias="containerType")
    container_sequence_number: Optional[StrictStr] = Field(default=None, description="An integer that must be submitted for multi-box shipments only, where one item may come in separate packages.", alias="containerSequenceNumber")
    container_identifiers: List[ContainerIdentification] = Field(description="A list of carton identifiers.", alias="containerIdentifiers")
    tracking_number: Optional[StrictStr] = Field(default=None, description="The tracking number used for identifying the shipment.", alias="trackingNumber")
    dimensions: Optional[Dimensions] = None
    weight: Optional[Weight] = None
    tier: Optional[StrictInt] = Field(default=None, description="Number of layers per pallet.")
    block: Optional[StrictInt] = Field(default=None, description="Number of cartons per layer on the pallet.")
    inner_containers_details: Optional[InnerContainersDetails] = Field(default=None, alias="innerContainersDetails")
    packed_items: Optional[List[PackedItems]] = Field(default=None, description="A list of packed items.", alias="packedItems")
    __properties: ClassVar[List[str]] = ["containerType", "containerSequenceNumber", "containerIdentifiers", "trackingNumber", "dimensions", "weight", "tier", "block", "innerContainersDetails", "packedItems"]

    @field_validator('container_type')
    def container_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['carton', 'pallet']):
            raise ValueError("must be one of enum values ('carton', 'pallet')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Containers from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in container_identifiers (list)
        _items = []
        if self.container_identifiers:
            for _item_container_identifiers in self.container_identifiers:
                if _item_container_identifiers:
                    _items.append(_item_container_identifiers.to_dict())
            _dict['containerIdentifiers'] = _items
        # override the default output from pydantic by calling `to_dict()` of dimensions
        if self.dimensions:
            _dict['dimensions'] = self.dimensions.to_dict()
        # override the default output from pydantic by calling `to_dict()` of weight
        if self.weight:
            _dict['weight'] = self.weight.to_dict()
        # override the default output from pydantic by calling `to_dict()` of inner_containers_details
        if self.inner_containers_details:
            _dict['innerContainersDetails'] = self.inner_containers_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in packed_items (list)
        _items = []
        if self.packed_items:
            for _item_packed_items in self.packed_items:
                if _item_packed_items:
                    _items.append(_item_packed_items.to_dict())
            _dict['packedItems'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Containers from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "containerType": obj.get("containerType"),
            "containerSequenceNumber": obj.get("containerSequenceNumber"),
            "containerIdentifiers": [ContainerIdentification.from_dict(_item) for _item in obj["containerIdentifiers"]] if obj.get("containerIdentifiers") is not None else None,
            "trackingNumber": obj.get("trackingNumber"),
            "dimensions": Dimensions.from_dict(obj["dimensions"]) if obj.get("dimensions") is not None else None,
            "weight": Weight.from_dict(obj["weight"]) if obj.get("weight") is not None else None,
            "tier": obj.get("tier"),
            "block": obj.get("block"),
            "innerContainersDetails": InnerContainersDetails.from_dict(obj["innerContainersDetails"]) if obj.get("innerContainersDetails") is not None else None,
            "packedItems": [PackedItems.from_dict(_item) for _item in obj["packedItems"]] if obj.get("packedItems") is not None else None
        })
        return _obj


